pub enum PythonImplementation {
CPython,
PyPy,
MicroPython,
GraalPy,
RustPython,
}Expand description
Python implementation label.
Variants
Implementations
Sourceimpl PythonImplementation
impl PythonImplementation
Sourcepub const fn as_str(self) -> &'static str
pub const fn as_str(self) -> &'static str
Returns the normalized implementation label.
Examples found in repository?
examples/basic_usage.rs (line 14)
6fn main() -> Result<(), Box<dyn std::error::Error>> {
7 let version: PythonVersion = "Python 3.12.1".parse()?;
8 let identifier = PythonIdentifier::new("async_task")?;
9 let requirement = PipRequirement::new("requests>=2")?;
10 let node_id = PytestNodeId::new("tests/test_app.py::test_smoke")?;
11
12 assert!(version.is_python3());
13 assert_eq!(identifier.as_str(), "async_task");
14 assert_eq!(PythonImplementation::CPython.as_str(), "cpython");
15 assert_eq!(PythonPrimitiveValue::None.type_name(), "NoneType");
16 assert!(!requirement.is_editable());
17 assert!(node_id.has_scope_separator());
18 Ok(())
19}Trait Implementations
Sourceimpl Clone for PythonImplementation
impl Clone for PythonImplementation
Sourcefn clone(&self) -> PythonImplementation
fn clone(&self) -> PythonImplementation
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PythonImplementation
impl Debug for PythonImplementation
Sourceimpl Display for PythonImplementation
impl Display for PythonImplementation
Sourceimpl FromStr for PythonImplementation
impl FromStr for PythonImplementation
Sourcetype Err = PythonVersionParseError
type Err = PythonVersionParseError
The associated error which can be returned from parsing.
Sourcefn from_str(
input: &str,
) -> Result<PythonImplementation, <PythonImplementation as FromStr>::Err>
fn from_str( input: &str, ) -> Result<PythonImplementation, <PythonImplementation as FromStr>::Err>
Parses a string
s to return a value of this type. Read moreSourceimpl Hash for PythonImplementation
impl Hash for PythonImplementation
Sourceimpl Ord for PythonImplementation
impl Ord for PythonImplementation
Sourcefn cmp(&self, other: &PythonImplementation) -> Ordering
fn cmp(&self, other: &PythonImplementation) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for PythonImplementation
impl PartialEq for PythonImplementation
Sourcefn eq(&self, other: &PythonImplementation) -> bool
fn eq(&self, other: &PythonImplementation) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for PythonImplementation
impl PartialOrd for PythonImplementation
impl Copy for PythonImplementation
impl Eq for PythonImplementation
impl StructuralPartialEq for PythonImplementation