pub struct PytestNodeId(/* private fields */);Expand description
pytest node ID metadata.
Implementations
Sourceimpl PytestNodeId
impl PytestNodeId
Sourcepub fn new(input: &str) -> Result<PytestNodeId, PytestNameError>
pub fn new(input: &str) -> Result<PytestNodeId, PytestNameError>
Creates pytest node ID metadata.
Errors
Returns PytestNameError::Empty when input is empty after trimming.
Examples found in repository?
examples/basic_usage.rs (line 10)
6fn main() -> Result<(), Box<dyn std::error::Error>> {
7 let version: PythonVersion = "Python 3.12.1".parse()?;
8 let identifier = PythonIdentifier::new("async_task")?;
9 let requirement = PipRequirement::new("requests>=2")?;
10 let node_id = PytestNodeId::new("tests/test_app.py::test_smoke")?;
11
12 assert!(version.is_python3());
13 assert_eq!(identifier.as_str(), "async_task");
14 assert_eq!(PythonImplementation::CPython.as_str(), "cpython");
15 assert_eq!(PythonPrimitiveValue::None.type_name(), "NoneType");
16 assert!(!requirement.is_editable());
17 assert!(node_id.has_scope_separator());
18 Ok(())
19}Sourcepub fn has_scope_separator(&self) -> bool
pub fn has_scope_separator(&self) -> bool
Returns whether the node ID contains a pytest :: separator.
Examples found in repository?
examples/basic_usage.rs (line 17)
6fn main() -> Result<(), Box<dyn std::error::Error>> {
7 let version: PythonVersion = "Python 3.12.1".parse()?;
8 let identifier = PythonIdentifier::new("async_task")?;
9 let requirement = PipRequirement::new("requests>=2")?;
10 let node_id = PytestNodeId::new("tests/test_app.py::test_smoke")?;
11
12 assert!(version.is_python3());
13 assert_eq!(identifier.as_str(), "async_task");
14 assert_eq!(PythonImplementation::CPython.as_str(), "cpython");
15 assert_eq!(PythonPrimitiveValue::None.type_name(), "NoneType");
16 assert!(!requirement.is_editable());
17 assert!(node_id.has_scope_separator());
18 Ok(())
19}Trait Implementations
Sourceimpl Clone for PytestNodeId
impl Clone for PytestNodeId
Sourcefn clone(&self) -> PytestNodeId
fn clone(&self) -> PytestNodeId
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PytestNodeId
impl Debug for PytestNodeId
Sourceimpl Display for PytestNodeId
impl Display for PytestNodeId
Sourceimpl FromStr for PytestNodeId
impl FromStr for PytestNodeId
Sourcetype Err = PytestNameError
type Err = PytestNameError
The associated error which can be returned from parsing.
Sourcefn from_str(input: &str) -> Result<PytestNodeId, <PytestNodeId as FromStr>::Err>
fn from_str(input: &str) -> Result<PytestNodeId, <PytestNodeId as FromStr>::Err>
Parses a string
s to return a value of this type. Read moreSourceimpl Hash for PytestNodeId
impl Hash for PytestNodeId
Sourceimpl Ord for PytestNodeId
impl Ord for PytestNodeId
Sourcefn cmp(&self, other: &PytestNodeId) -> Ordering
fn cmp(&self, other: &PytestNodeId) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for PytestNodeId
impl PartialEq for PytestNodeId
Sourcefn eq(&self, other: &PytestNodeId) -> bool
fn eq(&self, other: &PytestNodeId) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for PytestNodeId
impl PartialOrd for PytestNodeId
Sourceimpl TryFrom<&str> for PytestNodeId
impl TryFrom<&str> for PytestNodeId
Sourcetype Error = PytestNameError
type Error = PytestNameError
The type returned in the event of a conversion error.
Sourcefn try_from(
value: &str,
) -> Result<PytestNodeId, <PytestNodeId as TryFrom<&str>>::Error>
fn try_from( value: &str, ) -> Result<PytestNodeId, <PytestNodeId as TryFrom<&str>>::Error>
Performs the conversion.
impl Eq for PytestNodeId
impl StructuralPartialEq for PytestNodeId